library(loadeR)
library(transformeR)
library(ggplot2)
library(RColorBrewer)
library(maps)

rm(list=ls()) ; graphics.off() ; gc()

#Directory information
setwd("~/Documents/ETCCDI_eobs/")
OUTPUTS <- "OUTPUTS/"

#####################################
#Time series CPs
#Load CPs information
load("../WardCluster_Dendrogram_D2_50km.Rdata")
k=5

calendario <- seq(as.Date("1950-01-01"),as.Date("2021-12-31"),by="day")
fechas <- calendario[format(calendario,"%m-%d") != "02-29"]
seasons <- list(Summer=c(6,7,8),Autumn=c(9,10,11),Winter=c(12,1,2),Spring=c(3,4,5))

vector_cluster <- cutree(ward_clustering,k)[which(format(calendario,"%Y")%in%c(1950:2021))]
cp <- loadGridData(dataset = "../eobs_tasmax_spain.nc",lonLim = c(-1,1),latLim = c(35,36),var="tasmax")
cp <- aggregateGrid(cp,aggr.spatial = list(FUN="mean"))
for(l in 1:length(cp$Data)){
  cp$Data[l] <- vector_cluster[l]
}

data <- list() ; mix <- list()
for(l in 1:length(unique(vector_cluster))){
  v <- unique(vector_cluster)[l]
  cp2 <- cp
  cp2$Data[which(cp2$Data!=v)] <- 0
  cp2$Data[which(cp2$Data==v)] <- 1
  
  for(j in 1:length(seasons)){
    index.cp <- aggregateGrid(cp2,aggr.s = list(FUN=list("sum",na.rm=T),season=seasons[[j]]))
    data[[j]] <- data.frame(Index=index.cp$Data/90*100,Years=getYearsAsINDEX(index.cp),
                            Season=rep(names(seasons)[j],length(index.cp$Data)),
                            CP=rep(v,length(index.cp$Data)))
  }
  data[[5]] <- data.frame(Index=aggregateGrid(cp2,aggr.s = list(FUN=list("sum",na.rm=T),season=c(1:12)))$Data/365*100,Years=getYearsAsINDEX(index.cp),
                          Season=rep("Annual",length(index.cp$Data)),
                          CP=rep(v,length(index.cp$Data)))
  mix[[v]] <- do.call(rbind,data)
}

palette <- brewer.pal(n=7,name = "Set1")


mix <- do.call(rbind,mix)
mix2 <- subset(mix,mix$Season!="Annual")
mix2$CP <- factor(mix2$CP,levels=c(1:k))

png(filename = paste(OUTPUTS,"CPs_TimeSeries_D2k1_cols.png",sep=""),res=600,width=4000,height=2000)
print(ggplot(data=mix2,aes(x=Years,y=Index,fill=CP)) + geom_col() + theme_bw()+facet_wrap(~Season,nrow=2)+  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))+
        scale_x_continuous(n.breaks = 8) + coord_cartesian(expand=F)+ scale_y_continuous(n.breaks = 6) + ylab("Relative frequency (%)")+ scale_fill_manual(values=palette[1:k]),aesthetics=c("color","fill"))
# ggtitle(paste("CPs relative frequency","D2 k1",sep=" ")) + geom_smooth(method=lm,se=F,lwd=0.75))
dev.off()

##################
#Klee diagram
calendario <- seq(as.Date(paste(getYearsAsINDEX(cp)[1],"-01-01",sep="")),as.Date(paste(getYearsAsINDEX(cp)[length(getYearsAsINDEX(cp))],"-12-31",sep="")),by="day")
fechas <- calendario[format(calendario,"%m-%d") != "02-29"]

Year <- as.numeric(format(fechas,"%Y"))
Month <- as.numeric(format(fechas,"%m"))
Day <- rep(c(1:365),length(unique(Year)))

data <- data.frame(Year=Year,Month=Month,Day=Day,CP=cp$Data[format(calendario,"%m-%d") != "02-29"])
data$CP <- factor(data$CP,levels=c(1:k))

png(filename = paste(OUTPUTS,"CPs_Klee_D2k1_cols.png",sep=""),res=600,width=4000,height=2000)
print(ggplot(data=data,aes(x=Year,y=Day,fill=CP)) + geom_tile() +theme_bw()+theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))+
        scale_x_continuous(n.breaks = 8)+ coord_cartesian(expand=F)+scale_y_continuous(labels = c("J","F","M","A","M","J","J","A","S","O","N","D"),breaks = seq(15,365,by=30))+ scale_fill_manual(values=palette[1:k]),aesthetics=c("color","fill"))
# ggtitle(paste("CPs relative frequency","D2 k1",sep=" ")) + geom_smooth(method=lm,se=F,lwd=0.75))
dev.off()

#############
#Seasonal cycle
#Temporal cycle
calendario <- seq(as.Date("1950-01-01"),as.Date("2022-12-31"),by="day")
fechas <- calendario[format(calendario,"%m-%d") != "02-29"]
n_years <- length(fechas)/365

if(length(vector_cluster)!=length(fechas)){ #13149
  vector_cluster <- vector_cluster[which(calendario%in%fechas)]
  rm(calendario,fechas)
}

datos = data.frame(group=as.numeric( vector_cluster),
                   day=rep(1:365,n_years))

value <- matrix(NA,365,k)
for(i in 1:365){
  for(j in 1:k){
    value[i,j] <- length(which(datos$group==j & datos$day==i))/n_years*100
  }
}

palette <- brewer.pal(n=7,name = "Set1")

datos = data.frame(day=rep(1:365,k),frequency=as.numeric(value),group=factor(rep(1:k,each=365),levels=c(1:k)))
p <- ggplot(data=datos,aes(x=day,y=frequency,fill=group)) + geom_col() + 
  scale_fill_manual(name="CP",values=palette[1:k]) + theme_bw() + ggtitle("") + coord_cartesian(expand=F)+ xlab("Day") + ylab("Relative frequency (%)")+
  scale_x_continuous(labels = c("J","F","M","A","M","J","J","A","S","O","N","D"),breaks = seq(15,365,by=30))
ggsave(p,filename=paste(OUTPUTS,"relativefrequency_CPs_",dom,"_",k,"CPs.png",sep=""),device="png",
       dpi=600,width=4.84,height = 3.95)


