#Multiple-Scenarios: SSP126, SSP245, SSP585 plot
library(loadeR)
library(ggplot2)
library(RColorBrewer)
library(miceadds)

rm(list=ls()) ; graphics.off() ; gc()

#Working directory
setwd("~/Downloads/")
OUTPUTS <- "~/Downloads/"

#----------------------ANNUAL---------------------#
ssp126 <- load.Rdata2("ensemble_CMIP6_mon_ssp126_Catalonia.Rdata")
ssp126$Scenario <- "ssp126"
ssp245 <- load.Rdata2("ensemble_CMIP6_mon_ssp245_Catalonia.Rdata")
ssp245$Scenario <- "ssp245"
ssp585 <- load.Rdata2("ensemble_CMIP6_mon_ssp585_Catalonia.Rdata")
ssp585$Scenario <- "ssp585"

scenario <- rbind(ssp126,ssp245,ssp585)
region <- c("Catalonia","EuroMediterranean")

for(r in 1:2){
    ssp126 <- load.Rdata2(paste("ensemble_CMIP6_yr_ssp126_",region[r],".Rdata",sep=""))
    ssp126$Scenario <- "ssp126"
    ssp245 <- load.Rdata2(paste("ensemble_CMIP6_yr_ssp245_",region[r],".Rdata",sep=""))
    ssp245$Scenario <- "ssp245"
    ssp585 <- load.Rdata2(paste("ensemble_CMIP6_yr_ssp585_",region[r],".Rdata",sep=""))
    ssp585$Scenario <- "ssp585"
    
    scenario <- rbind(ssp126,ssp245,ssp585)
    scenario$Scenario <- factor(scenario$Scenario,levels=c("ssp585","ssp245","ssp126"))

  png(filename = paste(OUTPUTS,"AnnualIndices","_TimeSeries_CMIP6_",region[r],"_Historical+multiple.png",sep=""),res=300,width=2000,height=3000)
  print(ggplot(data=scenario,aes(x=Year))  + 
          geom_ribbon(aes(ymin=Min,ymax=Max,fill=Scenario),alpha=0.5) + ylab("Index Unit")+
          geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
          theme_bw() + facet_wrap(~Index,scales = "free_y",ncol=2)+ geom_line(aes(y=Serie,col=Scenario))+
          labs(title = paste("Annual ETCCDI precipitation and temperature indices over ",region[r],sep=""),
               subtitle = paste("CMIP6 Historical + Future",". Changes wrt 1981-2010",sep=""))+
          scale_color_manual(values=brewer.pal(3,"Set1"),aesthetics = c("colour","fill")))
  dev.off()  
}



#----------------------SEASONAL---------------------#
ssn <- c("Winter","Spring","Summer","Autumn")#,"Annual")
region <- c("Catalonia","EuroMediterranean")

for(r in 1:2){
  
seasons <- list()
  
for(s in 1:length(ssn)){
ssp126 <- load.Rdata2(paste("ensemble_CMIP6_mon_ssp126_",ssn[s],"_",region[r],".Rdata",sep=""))
ssp126$Scenario <- "ssp126"
ssp245 <- load.Rdata2(paste("ensemble_CMIP6_mon_ssp245_",ssn[s],"_",region[r],".Rdata",sep=""))
ssp245$Scenario <- "ssp245"
ssp585 <- load.Rdata2(paste("ensemble_CMIP6_mon_ssp585_",ssn[s],"_",region[r],".Rdata",sep=""))
ssp585$Scenario <- "ssp585"

scenario <- rbind(ssp126,ssp245,ssp585)
scenario$Season <- ssn[s]
scenario$Scenario <- factor(scenario$Scenario,levels=c("ssp585","ssp245","ssp126"))

seasons[[s]] <- scenario
}
  
seasons <- do.call("rbind",seasons)
seasons$Season <- factor(seasons$Season,levels=c("Summer","Autumn","Winter","Spring"))

png(filename = paste(OUTPUTS,"SeasonalIndices","_TimeSeries_CMIP6_",region[r],"_Historical+multiple.png",sep=""),res=300,width=2000,height=3000)
print(ggplot(data=seasons,aes(x=Year))  + 
        geom_ribbon(aes(ymin=Min,ymax=Max,fill=Scenario),alpha=0.5) + ylab("Index Unit")+
        geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
        theme_bw() + facet_grid(Index~Season,scales = "free_y")+ geom_line(aes(y=Serie,col=Scenario))+
        labs(title = paste("Seasonal ETCCDI precipitation and temperature indices over ",region[r],sep=""),
             subtitle = paste("CMIP6 Historical + Future",". Changes wrt 1981-2010",sep=""))+
      scale_color_manual(values=brewer.pal(3,"Set1"),aesthetics = c("colour","fill")))
dev.off()  
}
