library(loadeR)
library(ggplot2)
library(RColorBrewer)

rm(list=ls()) ; graphics.off() ; gc()

#Working directory
setwd("/esarchive/scratch/molmo/CLIMCAT_MJ/CORDEX/")
OUTPUTS <- "/esarchive/scratch/molmo/CLIMCAT_MJ/OUTPUTS/"

#----------------------ANNUAL---------------------#
scenario <- c("rcp26","rcp45","rcp85")

for(sc in 1:length(scenario)){
  
  message(scenario[sc])  
  
  #Load data
  load(paste("series.indices.yr.CORDEX.",scenario[sc],".Rdata",sep="")) #ssp585
  
  indices <- c("wsdi","csdi","tr",
               "r20mm","prcptot","cdd","cwd")
  
  test <- list()
  for(i in 1:length(indices)){
    test[[i]] <- list()
    for(m in 1:length(series.indices[[i]])){
      test[[i]][[m]] <- do.call("rbind",series.indices[[i]][[m]])
    }
  }
  
  test2 <- list()
  for(i in 1:length(indices)){
    test2[[i]] <- do.call("rbind",test[[i]])
  }
  
  test3 <- do.call("rbind",test2)
  
  Model <- unique(test3$Model)
  Model <- Model[order(Model)]
  
  test3$Model <- factor(test3$Model,levels=rev(Model))
  test3$Index <- toupper(test3$Index)
  test3$Index <- factor(test3$Index,levels=toupper(c("cdd","cwd","prcptot","r20mm","csdi","wsdi","tr")))
  
  #Ensemble
  q10 <- function(x){
    quantile(x,probs=0.1,na.rm=T)
  }
  
  q90 <- function(x){
    quantile(x,probs=0.9,na.rm=T)
  }
  
  q50 <- function(x){
    quantile(x,probs=0.5,na.rm=T)
  }
  
  region <- unique(test3$Region)
  for(r in 1:2){
    data <- test3[which(test3$Region==region[r]),]
    ensemble <- aggregate(Serie~Index+Year,data,FUN="q50")
    ensemble$Min <- aggregate(Serie~Index+Year,data,FUN="q10")$Serie
    ensemble$Max <-aggregate(Serie~Index+Year,data,FUN="q90")$Serie
    ensemble$Scenario <- scenario[sc]
    
    #Plot
    png(filename = paste(OUTPUTS,"AnnualIndices_TimeSeries_CORDEX_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
    print(ggplot(data=ensemble,aes(x=Year))  + 
            geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
            geom_hline(yintercept=0) + geom_vline(xintercept=2005,linetype="dotted")+
            theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
            labs(title = paste("Annual ETCCDI precipitation and temperature indices over ",region[r],sep=""),
                 subtitle = paste("CORDEX Historical + ",scenario[sc],". Changes wrt 1981-2010",sep="")))
    dev.off()
    
    save(ensemble,file=paste(OUTPUTS,"ensemble_CORDEX_yr_",scenario[sc],"_",region[r],".Rdata",sep=""))
  }
  
  
  #----------------------SEASONAL---------------------#
  load(paste("series.indices.mon.CORDEX.",scenario[sc],".Rdata",sep="")) #ssp585
  indices <- c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
               "rx5day","rx1day")
  
  test <- list()
  for(i in 1:length(indices)){
    test[[i]] <- list()
    for(m in 1:length(series.indices[[i]])){
      test[[i]][[m]] <- do.call("rbind",series.indices[[i]][[m]])
    }
  }
  
  test2 <- list()
  for(i in 1:length(indices)){
    test2[[i]] <- do.call("rbind",test[[i]])
  }
  
  test3 <- do.call("rbind",test2)
  
  Model <- unique(test3$Model)
  Model <- Model[order(Model)]
  
  test3$Model <- factor(test3$Model,levels=rev(Model))
  test3$Index <- toupper(test3$Index)
  test3$Index <- factor(test3$Index,levels=toupper(c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
                                                     "rx5day","rx1day")))

  
  region <- unique(test3$Region)
  for(r in 1:2){
    #Ensemble
    data <- test3[which(test3$Region==region[r]),]
    
    #Plot by season
    ssn <- c("Winter","Spring","Summer","Autumn")#,"Annual")
    
    for(i in 1:4){
      data2 <- data[which(data$Season==ssn[i]),]
      ensemble <- aggregate(Serie~Index+Year,data2,FUN="q50")
      ensemble$Min <- aggregate(Serie~Index+Year,data2,FUN="q10")$Serie
      ensemble$Max <- aggregate(Serie~Index+Year,data2,FUN="q90")$Serie
      ensemble$Scenario <- scenario[sc]
      
      save(ensemble,file=paste(OUTPUTS,"ensemble_CORDEX_mon_",scenario[sc],"_",ssn[i],"_",region[r],".Rdata",sep=""))
      
      #Temperature indices
      ensemble2 <- subset(ensemble,Index%in%toupper(c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p")))
      png(filename = paste(OUTPUTS,"SeasonalIndices_TX_TN_",ssn[i],"_TimeSeries_CORDEX_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
      print(ggplot(data=ensemble2,aes(x=Year))  + 
              geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
              geom_hline(yintercept=0) + geom_vline(xintercept=2005,linetype="dotted")+
              theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
              labs(title = paste(ssn[i]," ETCCDI temperature indices over ",region[r],sep=""),
                   subtitle = paste("CORDEX Historical + ",scenario[sc],". Changes wrt 1981-2010")))
      dev.off()
      
      #Precipitation indices
      ensemble2 <- subset(ensemble,Index%in%toupper(c("rx1day","rx5day","tnx","tnn","tx90p","tx10p","tn90p","tn10p")))
      png(filename = paste(OUTPUTS,"SeasonalIndices_PR_",ssn[i],"_TimeSeries_CORDEX_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
      print(ggplot(data=ensemble2,aes(x=Year))  + 
              geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
              geom_hline(yintercept=0) + geom_vline(xintercept=2005,linetype="dotted")+
              theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
              labs(title = paste(ssn[i]," ETCCDI precipitation indices over ",region[r],sep=""),
                   subtitle = paste("CORDEX Historical + ",scenario[sc],". Changes wrt 1981-2010",sep="")))
      dev.off()
    }
    
    #Plot all seasons
    seasons <- list()
    
    for(s in 1:4){
      data2 <- data[which(data$Season==ssn[s]),]
      ensemble <- aggregate(Serie~Index+Year,data2,FUN="q50")
      ensemble$Min <- aggregate(Serie~Index+Year,data2,FUN="q10")$Serie
      ensemble$Max <- aggregate(Serie~Index+Year,data2,FUN="q90")$Serie
      ensemble$Season <- ssn[s]
      seasons[[s]] <- ensemble
    }
    
    seasons <- do.call("rbind",seasons)
    seasons$Season <- factor(seasons$Season,levels=c("Summer","Autumn","Winter","Spring"))
    png(filename = paste(OUTPUTS,"SeasonalIndices","_TimeSeries_CORDEX_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
    print(ggplot(data=seasons,aes(x=Year))  + 
            geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
            geom_hline(yintercept=0) + geom_vline(xintercept=2005,linetype="dotted")+
            theme_bw() + facet_grid(Index~Season,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
            labs(title = paste("Seasonal ETCCDI precipitation and temperature indices over ",region[r],sep=""),
                 subtitle = paste("CORDEX Historical + ",scenario[sc],". Changes wrt 1981-2010",sep="")))
    dev.off()
  }
}
